@@ -76,7 +76,11 @@ sub clear_changes {
 
 sub groups {
     my $self = shift;
-    return sort keys %{ $self->{ changes } };
+    my %args = @_;
+
+    $args{ sort } ||= sub { sort @_ };
+
+    return $args{ sort }->( keys %{ $self->{ changes } } );
 }
 
 sub add_group {
@@ -96,18 +100,19 @@ sub delete_group {
 sub delete_empty_groups {
     my $self = shift;
 
-    $self->delete_group(
-        grep { ! @{ $self->changes($_) } } $self->groups
-    );
+    $self->delete_group( grep { !@{ $self->changes( $_ ) } } $self->groups );
 }
 
 sub serialize {
     my $self = shift;
+    my %args = @_;
 
-    my $output = sprintf "%s %s\n", $self->version, $self->date;
+    my $output = join( ' ', grep { defined } ( $self->version, $self->date ) )
+        . "\n";
 
-    $output
-        .= join( "\n", map { $self->_serialize_group( $_ ) } $self->groups );
+    $output .= join "\n",
+        map { $self->_serialize_group( $_ ) }
+        $self->groups( sort => $args{ group_sort } );
     $output .= "\n";
 
     return $output;
@@ -193,10 +198,14 @@ a C<group> option will only replace change items in that group.
 
 Clears all changes from the release.
 
-=head2 groups( )
+=head2 groups( sort => \&sorting_function )
 
 Returns a list of current groups in this release.
 
+If I<sort> is provided, groups are
+sorted according to the given function. If not,
+they are sorted alphabetically.
+
 =head2 add_group( @groups )
 
 Creates an empty group under the names provided.
@@ -209,11 +218,15 @@ Deletes the groups of changes specified.
 
 Deletes all groups that don't contain any changes.
 
-=head2 serialize( )
+=head2 serialize( group_sort => \&sorting_function )
 
 Returns the release data as a string, suitable for inclusion in a Changes 
 file.
 
+If I<group_sort> is provided, change groups are
+sorted according to the given function. If not,
+groups are sorted alphabetically.
+
 =head1 SEE ALSO
 
 =over 4
